@@ -1,4 +1,4 @@
 from soam.reporting.gsheets_report import GSheetsReportTask
 from soam.reporting.mail_report import MailReportTask
-from soam.reporting.pdf_report import IpynbToPDF
+from soam.reporting.pdf_report import PDFReportTask
 from soam.reporting.slack_report import SlackReportTask
